==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files_external/l10n/nl.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Ophalen aanvraag tokens mislukt. Verifieer dat je app sleutel en geheime sleutel juist zijn.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Ophalen toegangstokens mislukt. Verifieer dat je app sleutel en geheime sleutel juist zijn.",
    "Please provide a valid app key and secret." : "Geef een geldige app sleutel en geheime sleutel op.",
    "Step 1 failed. Exception: %s" : "Stap 1 is mislukt. Uitzondering: %s",
    "Step 2 failed. Exception: %s" : "Stap 2 is mislukt. Uitzondering: %s",
    "External storage" : "Externe opslag",
    "Dropbox App Configuration" : "Dropbox app configuratie",
    "Google Drive App Configuration" : "Google Drive app configuratie",
    "Personal" : "Persoonlijk",
    "System" : "Systeem",
    "Grant access" : "Sta toegang toe",
    "Error configuring OAuth1" : "Fout bij configureren OAuth1",
    "Error configuring OAuth2" : "Fout bij configureren OAuth2",
    "Generate keys" : "Genereer sleutels",
    "Error generating key pair" : "Fout bij genereren sleutelpaar",
    "All users. Type to select user or group." : "Alle gebruikers. Tikken om een gebruiker of groep te selecteren.",
    "(group)" : "(groep)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibiliteit met Mac NFD encoding (traag)",
    "Admin defined" : "Beheerder gedefinieerd",
    "Saved" : "Bewaard",
    "Saving..." : "Bewaren...",
    "Save" : "Bewaren",
    "Empty response from the server" : "Lege reactie van de server",
    "Couldn't access. Please logout and login to activate this mount point" : "Geen toegang. Log uit en opnieuw in om dit koppelpunt te activeren",
    "Couldn't get the information from the remote server: {code} {type}" : "Kon geen informatie van de externe server krijgen: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Kon geen overzicht met externe koppelpunten krijgen: {type}",
    "There was an error with message: " : "Er was een fout met de volgende melding:",
    "External mount error" : "Extern koppelpunt fout",
    "external-storage" : "externe opslag",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Kon geen overzicht met Windows netwerk koppelpunten krijgen: lege reactie van de server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Sommige van de geconfigureerde koppelpunten zijn niet verbonden. Klik op de rode rij(en) voor meer informatie",
    "Please enter the credentials for the {mount} mount" : "Geef de inloggegevens op voor de {mount} mount",
    "Username" : "Gebruikersnaam",
    "Password" : "Wachtwoord",
    "Credentials saved" : "Inloggegevens opgeslagen",
    "Credentials saving failed" : "Opslaan inloggegevens mislukt",
    "Credentials required" : "Inloggegevens vereist",
    "Storage with id \"%i\" not found" : "Opslag met id \"%i\" niet gevonden",
    "Invalid backend or authentication mechanism class" : "Ongeldige backend of authenticatie mechanisme klasse",
    "Invalid mount point" : "Ongeldig aankoppelpunt",
    "Objectstore forbidden" : "Objectopslag verboden",
    "Invalid storage backend \"%s\"" : "Ongeldig opslagsysteem \"%s\"",
    "Not permitted to use backend \"%s\"" : "Niet toegestaan om \"%s\" te gebruiken",
    "Not permitted to use authentication mechanism \"%s\"" : "Niet toegestaan om authenticatiemechanisme \"%s\" te gebruiken",
    "Unsatisfied backend parameters" : "Onvoldoende backend parameters",
    "Unsatisfied authentication mechanism parameters" : "Onvoldoende authenticatiemechanisme parameters",
    "Insufficient data: %s" : "Onvoldoende gegevens: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Opslag met id \"%i\" is niet te bewerken door gebruiker",
    "Access key" : "Access Key",
    "Secret key" : "Geheime sleutel",
    "Builtin" : "Ingebouwd",
    "None" : "Geen",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Naam tenant",
    "Identity endpoint URL" : "Identiteiten endpoint URL",
    "Rackspace" : "Rackspace",
    "API key" : "API sleutel",
    "Global credentials" : "Algemene inloggegevens",
    "Log-in credentials, save in database" : "Inloggegevens, bewaren in de database",
    "Username and password" : "Gebruikersnaam en wachtwoord",
    "Log-in credentials, save in session" : "Inloggegevens, opslaan in sessie",
    "User entered, store in database" : "Gebruiker opgegeven, opslaan in de database",
    "RSA public key" : "RSA publieke sleutel",
    "Public key" : "Publieke sleutel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hostnaam",
    "Port" : "Poort",
    "Region" : "Regio",
    "Enable SSL" : "Activeren SSL",
    "Enable Path Style" : "Activeren pad stijl",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Externe submap",
    "Secure https://" : "Secure https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokaal",
    "Location" : "Locatie",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP met geheime sleutel inlog",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domein",
    "SMB / CIFS using OC login" : "SMB / CIFS via OC inlog",
    "Username as share" : "Gebruikersnaam als share",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Servicenaam",
    "Request timeout (seconds)" : "Aanvraag time-out (seconds)",
    "External storages" : "Externe opslag",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Curl ondersteuning in PHP is niet geactiveerd of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je systeembeheerder dit te installeren.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP ondersteuning in PHP is niet geactiveerd of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je beheerder dit te installeren.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" is niet geïnstalleerd. Mounten van %s is niet mogelijk. Vraag uw beheerder om dit te installeren.",
    "No external storage configured" : "Geen externe opslag geconfigureerd",
    "You can add external storages in the personal settings" : "Je kunt externe opslag toevoegen in persoonlijke instellingen",
    "Name" : "Naam",
    "Storage type" : "Opslagtype",
    "Scope" : "Scope",
    "Enable encryption" : "Versleuteling inschakelen",
    "Enable previews" : "Activeren voorbeelden",
    "Enable sharing" : "Activeren delen",
    "Check for changes" : "Controleren op wijzigingen",
    "Never" : "Nooit",
    "Once every direct access" : "Een keer bij elke directe toegang",
    "Folder name" : "Mapnaam",
    "Authentication" : "Authenticatie",
    "Configuration" : "Configuratie",
    "Available for" : "Beschikbaar voor",
    "Add storage" : "Toevoegen opslag",
    "Advanced settings" : "Geavanceerde instellingen",
    "Delete" : "Verwijder",
    "Allow users to mount external storage" : "Sta gebruikers toe om een externe opslag aan te koppelen",
    "Allow users to mount the following external storage" : "Sta gebruikers toe de volgende externe opslag aan te koppelen",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Kon geen informatie van de ownCloud server krijgen: {code} {type}",
    "Access granted" : "Toegang verleend",
    "Global Credentials" : "Algemene inloggegevens",
    "ownCloud" : "ownCloud",
    "<b>Note:</b> " : "<b>Let op:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Let op:</b> Curl ondersteuning in PHP is niet geactiveerd of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je systeembeheerder dit te installeren.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Let op:</b> FTP ondersteuning in PHP is niet geactiveerd of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je beheerder dit te installeren.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Let op:</b> \"%s\" is niet geïnstalleerd. Mounten van %s is niet mogelijk. Vraag uw beheerder om dit te installeren.",
    "External Storage" : "Externe opslag"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/files_external/l10n/nl.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Externe opslag",
    "Personal" : "Persoonlijk",
    "System" : "Systeem",
    "Grant access" : "Sta toegang toe",
    "Error configuring OAuth1" : "Fout bij configureren OAuth1",
    "Please provide a valid app key and secret." : "Geef een geldige app sleutel en geheime sleutel op.",
    "Error configuring OAuth2" : "Fout bij configureren OAuth2",
    "Generate keys" : "Genereer sleutels",
    "Error generating key pair" : "Fout bij genereren sleutelpaar",
    "All users. Type to select user or group." : "Alle gebruikers. Tikken om een gebruiker of groep te selecteren.",
    "(group)" : "(groep)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibiliteit met Mac NFD encoding (traag)",
    "Admin defined" : "Beheerder gedefinieerd",
    "Are you sure you want to delete this external storage" : "Weet je zeker dat je de externe opslag wilt verwijderen?",
    "Delete storage?" : "Opslag verwijderen?",
    "Saved" : "Bewaard",
    "Saving..." : "Bewaren...",
    "Save" : "Bewaren",
    "Empty response from the server" : "Lege reactie van de server",
    "Couldn't access. Please log out and in again to activate this mount point" : "Kon geen toegang krijgen. Log uit en opnieuw in om dit koppelpunt te activeren",
    "Couldn't get the information from the remote server: {code} {type}" : "Kon geen informatie van de externe server krijgen: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Kon geen overzicht met externe koppelpunten krijgen: {type}",
    "There was an error with message: " : "Er was een fout met de volgende melding:",
    "External mount error" : "Extern koppelpunt fout",
    "external-storage" : "externe opslag",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Kon geen overzicht met Windows netwerk koppelpunten krijgen: Maak de server reactie leeg",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Sommige van de geconfigureerde koppelpunten zijn niet verbonden. Klik op de rode rij(en) voor meer informatie",
    "Please enter the credentials for the {mount} mount" : "Geef de inloggegevens op voor de {mount} mount",
    "Username" : "Gebruikersnaam",
    "Password" : "Wachtwoord",
    "Credentials saved" : "Inloggegevens opgeslagen",
    "Credentials saving failed" : "Opslaan inloggegevens mislukt",
    "Credentials required" : "Inloggegevens vereist",
    "Storage with ID \"%d\" not found" : "Opslag met ID \"%d\" niet gevonden",
    "Invalid backend or authentication mechanism class" : "Ongeldige backend of authenticatie mechanisme klasse",
    "Invalid mount point" : "Ongeldig aankoppelpunt",
    "Objectstore forbidden" : "Objectopslag verboden",
    "Invalid storage backend \"%s\"" : "Ongeldig opslagsysteem \"%s\"",
    "Not permitted to use backend \"%s\"" : "Niet toegestaan om \"%s\" te gebruiken",
    "Not permitted to use authentication mechanism \"%s\"" : "Niet toegestaan om authenticatiemechanisme \"%s\" te gebruiken",
    "Unsatisfied backend parameters" : "Onvoldoende backend parameters",
    "Unsatisfied authentication mechanism parameters" : "Onvoldoende authenticatiemechanisme parameters",
    "Insufficient data: %s" : "Onvoldoende gegevens: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Opslag met ID \"%d\" is niet door gebruikers te bewerken",
    "Access key" : "Access Key",
    "Secret key" : "Geheime sleutel",
    "Builtin" : "Ingebouwd",
    "None" : "Geen",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Naam tenant",
    "Identity endpoint URL" : "Identiteiten endpoint URL",
    "Rackspace" : "Rackspace",
    "API key" : "API sleutel",
    "Global credentials" : "Algemene inloggegevens",
    "Log-in credentials, save in database" : "Inloggegevens, bewaren in de database",
    "Username and password" : "Gebruikersnaam en wachtwoord",
    "Log-in credentials, save in session" : "Inloggegevens, opslaan in sessie",
    "User entered, store in database" : "Gebruiker opgegeven, opslaan in de database",
    "RSA public key" : "RSA publieke sleutel",
    "Public key" : "Publieke sleutel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hostnaam",
    "Port" : "Poort",
    "Region" : "Regio",
    "Enable SSL" : "Activeren SSL",
    "Enable Path Style" : "Activeren pad stijl",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Externe submap",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Lokaal",
    "Location" : "Locatie",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP met geheime sleutel inlog",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domein",
    "SMB / CIFS using OC login" : "SMB / CIFS via OC inlog",
    "Username as share" : "Gebruikersnaam als share",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Servicenaam",
    "Request timeout (seconds)" : "Aanvraag time-out (seconds)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Curl ondersteuning in PHP is niet ingeschakeld of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je systeembeheerder dit te installeren.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP ondersteuning in PHP is niet ingeschakeld of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je beheerder dit te installeren.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" is niet geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je beheerder om dit te installeren.",
    "No external storage configured" : "Geen externe opslag geconfigureerd",
    "You can add external storages in the personal settings" : "Je kunt externe opslag toevoegen in persoonlijke instellingen",
    "Name" : "Naam",
    "Storage type" : "Opslagtype",
    "Scope" : "Scope",
    "Enable encryption" : "Versleuteling inschakelen",
    "Enable previews" : "Activeren voorbeelden",
    "Enable sharing" : "Activeren delen",
    "Check for changes" : "Controleren op wijzigingen",
    "Never" : "Nooit",
    "Once every direct access" : "Een keer bij elke directe toegang",
    "Folder name" : "Mapnaam",
    "External storage" : "Externe opslag",
    "Authentication" : "Authenticatie",
    "Configuration" : "Configuratie",
    "Available for" : "Beschikbaar voor",
    "Add storage" : "Toevoegen opslag",
    "Advanced settings" : "Geavanceerde instellingen",
    "Delete" : "Verwijder",
    "Allow users to mount external storage" : "Sta gebruikers toe om een externe opslag aan te koppelen",
    "Allow users to mount the following external storage" : "Sta gebruikers toe de volgende externe opslag aan te koppelen",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Ophalen aanvraag tokens mislukt. Verifieer dat je app sleutel en geheime sleutel juist zijn.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Ophalen toegangstokens mislukt. Verifieer dat je app sleutel en geheime sleutel juist zijn.",
    "Step 1 failed. Exception: %s" : "Stap 1 is mislukt. Uitzondering: %s",
    "Step 2 failed. Exception: %s" : "Stap 2 is mislukt. Uitzondering: %s",
    "Dropbox App Configuration" : "Dropbox app configuratie",
    "Google Drive App Configuration" : "Google Drive app configuratie",
    "Storage with id \"%i\" not found" : "Opslag met id \"%i\" niet gevonden",
    "Storage with id \"%i\" is not user editable" : "Opslag met id \"%i\" is niet te bewerken door gebruiker",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive"
},
"nplurals=2; plural=(n != 1);");
